==> sql_result-0.2.0.tar.gz: lib/sql_result.dart <==
library sql_result;

import 'package:sql_recase/sql_recase.dart';

/// Each row returned from a query
class SqlRow {

  SqlRow();

  SqlResult _sqlResult;
  List _values;

  dynamic operator [](int index) => _values[index];

  void forEach(void f(n, v)) {
    _sqlResult?._fieldIndexes?.forEach((k, v) {
      f(k, _values[v]);
    });
  }

  Map<String, dynamic> toJson({recaseKey=recaseKeyNone}) {
    Map<String, dynamic> map = Map();
    int i = 0;
    _sqlResult?._fieldIndexes?.forEach((k, v) {
      map[recaseKey(k)] = _values[i++];
    });
    return map;
  }

  @override  
  noSuchMethod(Invocation invocation) {
    if (invocation.isGetter) {
      String name = invocation.memberName.toString().substring(8); // Symbol("columnName")
      name = name.substring(0,name.length-2);
      var i = _sqlResult._fieldIndexes[name];
      if (i != null) {
        return _values[i];
      }
    }
    return super.noSuchMethod(invocation);
  }
}

/// Result set returned from a query
class SqlResult  {
  SqlResult({this.columns, this.rows}) {
    if (this.columns == null) {
      this.columns = List<String>();
    }
    if (this.rows == null) {
      this.rows = List();
    }
  }

  /// List<String> with column names
  List<String> columns = List();

  /// List of [SqlRow] objects with all returned rows from a query
  List rows = List();

  /// Number of rows affected by last insert, update or delete command
  int rowsAffected = -1;
  Map<String, int> _fieldIndexes = Map();

  void updateFieldIndexes() {
    int i = 0;
    columns?.forEach((c) {
      _fieldIndexes[c] = i;
      i++;
    });
  }

  List values(String fieldName) {
    int i = _fieldIndexes[fieldName];
    if (i == null) {
      throw "Field [$fieldName] not found";
    }
    return rows.map((e) => e._values[i]).toList();
  }

  /// Returns a String of [fieldName] values separated by comma
  String ids(String fieldName) {
    String result = values(fieldName).join(",");
    if (result == "") {
      result = "-1";
    }
    return result;
  }

  SqlResult.fromJson(Map<String, dynamic> json) {
    columns = json["columns"]?.cast<String>();
    rows = json["rows"].map((e) {
      SqlRow r = SqlRow();
      r._sqlResult = this;
      r._values = e;
      return r;
    }).toList();
    rowsAffected = json["rowsAffected"];
    _fieldIndexes = Map();
    updateFieldIndexes();
  }

  Map<String, dynamic> toJson() {
    return {
      "columns": columns,
      "rows": rows.map((r) => r._values).toList(),
      "rowsAffected": rowsAffected,
    };
  }  
}

==> sql_result-0.2.1.tar.gz: lib/sql_result.dart <==
library sql_result;

import 'package:sql_recase/sql_recase.dart';

/// Each row returned from a query
class SqlRow {

  SqlRow();

  SqlResult _sqlResult;
  List _values;

  dynamic operator [](int index) => _values[index];

  /// Converts this row to a json map (with optional recase map keys)
  Map<String, dynamic> toJson({recaseKey=recaseKeyNone}) {
    Map<String, dynamic> map = Map();
    int i = 0;
    _sqlResult?._fieldIndexes?.forEach((k, v) {
      map[recaseKey(k)] = _values[i++];
    });
    return map;
  }

  @override  
  noSuchMethod(Invocation invocation) {
    if (invocation.isGetter) {
      String name = invocation.memberName.toString().substring(8); // Symbol("columnName")
      name = name.substring(0,name.length-2);
      var i = _sqlResult._fieldIndexes[name];
      if (i != null) {
        return _values[i];
      }
    }
    return super.noSuchMethod(invocation);
  }
}

/// Result set returned from a query
class SqlResult  {
  SqlResult({this.columns, this.rows}) {
    if (this.columns == null) {
      this.columns = List<String>();
    }
    if (this.rows == null) {
      this.rows = List();
    }
  }

  /// List<String> with column names
  List<String> columns = List();

  /// List of [SqlRow] objects with all returned rows from a query
  List rows = List();

  /// Number of rows affected by last insert, update or delete command
  int rowsAffected = -1;
  Map<String, int> _fieldIndexes = Map();

  void _updateFieldIndexes() {
    int i = 0;
    columns?.forEach((c) {
      _fieldIndexes[c] = i;
      i++;
    });
  }

  // Returns a list of [fieldName] values of entire result set
  List values(String fieldName) {
    int i = _fieldIndexes[fieldName];
    if (i == null) {
      throw "Field [$fieldName] not found";
    }
    return rows.map((e) => e._values[i]).toList();
  }

  /// Returns a String of [fieldName] values of entire result set separated by comma
  String ids(String fieldName) {
    String result = values(fieldName).join(",");
    if (result == "") {
      result = "-1";
    }
    return result;
  }

  /// Create a SqlResult object from a json map (useful for serialization)
  SqlResult.fromJson(Map<String, dynamic> json) {
    columns = json["columns"]?.cast<String>();
    rows = json["rows"].map((e) {
      SqlRow r = SqlRow();
      r._sqlResult = this;
      r._values = e;
      return r;
    }).toList();
    rowsAffected = json["rowsAffected"];
    _fieldIndexes = Map();
    _updateFieldIndexes();
  }

  /// Serialize SqlResult object to a json map
  Map<String, dynamic> toJson() {
    return {
      "columns": columns,
      "rows": rows.map((r) => r._values).toList(),
      "rowsAffected": rowsAffected,
    };
  }  
}
